vm

package
v0.2.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2026 License: MIT Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Command

func Command(h Actions) *cobra.Command

Command builds the "vm" parent command with all subcommands.

Types

type Actions

type Actions interface {
	Create(cmd *cobra.Command, args []string) error
	Run(cmd *cobra.Command, args []string) error
	Clone(cmd *cobra.Command, args []string) error
	Start(cmd *cobra.Command, args []string) error
	Stop(cmd *cobra.Command, args []string) error
	List(cmd *cobra.Command, args []string) error
	Inspect(cmd *cobra.Command, args []string) error
	Console(cmd *cobra.Command, args []string) error
	RM(cmd *cobra.Command, args []string) error
	Restore(cmd *cobra.Command, args []string) error
	Debug(cmd *cobra.Command, args []string) error
	Status(cmd *cobra.Command, args []string) error
}

Actions defines VM lifecycle operations.

type Handler

type Handler struct {
	cmdcore.BaseHandler
}

func (Handler) Clone

func (h Handler) Clone(cmd *cobra.Command, args []string) error

func (Handler) Console

func (h Handler) Console(cmd *cobra.Command, args []string) error

func (Handler) Create

func (h Handler) Create(cmd *cobra.Command, args []string) error

func (Handler) Debug

func (h Handler) Debug(cmd *cobra.Command, args []string) error

func (Handler) Inspect

func (h Handler) Inspect(cmd *cobra.Command, args []string) error

func (Handler) List

func (h Handler) List(cmd *cobra.Command, _ []string) error

func (Handler) RM

func (h Handler) RM(cmd *cobra.Command, args []string) error

RM deletes VMs. hyper.Delete uses best-effort semantics: it logs successfully deleted VMs in the returned slice even when later deletions fail, so we always report the partial results before checking the error.

func (Handler) Restore

func (h Handler) Restore(cmd *cobra.Command, args []string) error

func (Handler) Run

func (h Handler) Run(cmd *cobra.Command, args []string) error

func (Handler) Start

func (h Handler) Start(cmd *cobra.Command, args []string) error

func (Handler) Status added in v0.2.6

func (h Handler) Status(cmd *cobra.Command, args []string) error

func (Handler) Stop

func (h Handler) Stop(cmd *cobra.Command, args []string) error

Jump to