Documentation
¶
Index ¶
- func Command(h Actions) *cobra.Command
- type Actions
- type Handler
- func (h Handler) Clone(cmd *cobra.Command, args []string) error
- func (h Handler) Console(cmd *cobra.Command, args []string) error
- func (h Handler) Create(cmd *cobra.Command, args []string) error
- func (h Handler) Debug(cmd *cobra.Command, args []string) error
- func (h Handler) Inspect(cmd *cobra.Command, args []string) error
- func (h Handler) List(cmd *cobra.Command, _ []string) error
- func (h Handler) RM(cmd *cobra.Command, args []string) error
- func (h Handler) Restore(cmd *cobra.Command, args []string) error
- func (h Handler) Run(cmd *cobra.Command, args []string) error
- func (h Handler) Start(cmd *cobra.Command, args []string) error
- func (h Handler) Status(cmd *cobra.Command, args []string) error
- func (h Handler) Stop(cmd *cobra.Command, args []string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Actions ¶
type Actions interface {
Create(cmd *cobra.Command, args []string) error
Run(cmd *cobra.Command, args []string) error
Clone(cmd *cobra.Command, args []string) error
Start(cmd *cobra.Command, args []string) error
Stop(cmd *cobra.Command, args []string) error
List(cmd *cobra.Command, args []string) error
Inspect(cmd *cobra.Command, args []string) error
Console(cmd *cobra.Command, args []string) error
RM(cmd *cobra.Command, args []string) error
Restore(cmd *cobra.Command, args []string) error
Debug(cmd *cobra.Command, args []string) error
Status(cmd *cobra.Command, args []string) error
}
Actions defines VM lifecycle operations.
type Handler ¶
type Handler struct {
cmdcore.BaseHandler
}
func (Handler) RM ¶
RM deletes VMs. hyper.Delete uses best-effort semantics: it logs successfully deleted VMs in the returned slice even when later deletions fail, so we always report the partial results before checking the error.
Click to show internal directories.
Click to hide internal directories.