Documentation
¶
Index ¶
- type Config
- type OCI
- func (o *OCI) Config(ctx context.Context, vms []*types.VMConfig) (result [][]*types.StorageConfig, boot []*types.BootConfig, err error)
- func (o *OCI) Delete(ctx context.Context, ids []string) ([]string, error)
- func (o *OCI) GCModule() gc.Module[images.ImageGCSnapshot]
- func (o *OCI) Import(ctx context.Context, name string, tracker progress.Tracker, file ...string) error
- func (o *OCI) ImportFromReader(ctx context.Context, name string, tracker progress.Tracker, r io.Reader) error
- func (o *OCI) Inspect(ctx context.Context, id string) (*types.Image, error)
- func (o *OCI) List(ctx context.Context) ([]*types.Image, error)
- func (o *OCI) Pull(ctx context.Context, image string, _ bool, tracker progress.Tracker) error
- func (o *OCI) RegisterGC(orch *gc.Orchestrator)
- func (o *OCI) Type() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
images.BaseConfig
}
func (*Config) BootBaseDir ¶
func (*Config) EnsureDirs ¶
func (*Config) InitrdPath ¶
func (*Config) KernelPath ¶
type OCI ¶
type OCI struct {
// contains filtered or unexported fields
}
OCI converts OCI container layers to EROFS for Cloud Hypervisor.
func (*OCI) Config ¶
func (o *OCI) Config(ctx context.Context, vms []*types.VMConfig) (result [][]*types.StorageConfig, boot []*types.BootConfig, err error)
Config builds StorageConfig + BootConfig from layer digests; errors if any blob is missing.
func (*OCI) Import ¶
func (o *OCI) Import(ctx context.Context, name string, tracker progress.Tracker, file ...string) error
Import: each tar file becomes one EROFS layer in the order of the files slice.
func (*OCI) ImportFromReader ¶ added in v0.2.7
func (*OCI) Pull ¶
Pull downloads an OCI image, extracts boot files, and converts each layer to EROFS concurrently.
func (*OCI) RegisterGC ¶
func (o *OCI) RegisterGC(orch *gc.Orchestrator)
Click to show internal directories.
Click to hide internal directories.